@@ -67,9 +67,6 @@ typedef __int64 int64_t;
 
 #define MONGO_32(b) (BYTE4_32(b) | BYTE3_32(b) | BYTE2_32(b) | BYTE1_32(b))
 
-#define MONGO_32p(b) (((int)((unsigned char)b[0])) | ((int)((unsigned char)b[1]) << 8) | \
-                      ((int)((unsigned char)b[2]) << 16) | ((int)((unsigned char)b[3]) << 24))
-
 #define BYTE1_64(b) ((b & 0xff00000000000000ll) >> 56)
 #define BYTE2_64(b) ((b & 0x00ff000000000000ll) >> 40)
 #define BYTE3_64(b) ((b & 0x0000ff0000000000ll) >> 24)
@@ -82,17 +79,10 @@ typedef __int64 int64_t;
 #define MONGO_64(b) (BYTE8_64(b) | BYTE7_64(b) | BYTE6_64(b) | BYTE5_64(b) | \
                      BYTE4_64(b) | BYTE3_64(b) | BYTE2_64(b) | BYTE1_64(b))
 
-#define MONGO_64p(b) (((int64_t)((unsigned char)b[0])) | ((int64_t)((unsigned char)b[1]) << 8) | \
-                      ((int64_t)((unsigned char)b[2]) << 16) | ((int64_t)((unsigned char)b[3]) << 24) | \
-                      ((int64_t)((unsigned char)b[4]) << 32) | ((int64_t)((unsigned char)b[5]) << 40) | \
-                      ((int64_t)((unsigned char)b[6]) << 48) | ((int64_t)((unsigned char)b[7]) << 56))
-
 #else
 #define MONGO_32(b) (b)
-#define MONGO_32p(b) *((int*)(b))
 
 #define MONGO_64(b) (b)
-#define MONGO_64p(b) *((int64_t*)(b))
 #endif
 
 
@@ -128,6 +118,7 @@ typedef __int64 int64_t;
 #endif
 #define BSON_MAXKEY 127
 
+#define INITIAL_BUF_SIZE 4096
 #define GROW_SLOWLY 1048576
 #define MAX_OBJ_SIZE (1024*1024*4)
 
@@ -169,7 +160,7 @@ SV *perl_mongo_construct_instance_with_magic (const char *klass, void *ptr, MGVT
 // serialization
 SV *perl_mongo_buffer_to_sv(buffer * buffer, char * dt_type, int inflate_dbrefs, int inflate_regexps, SV * client);
 SV *perl_mongo_bson_to_sv (const bson_t * bson, char *dt_type, int inflate_dbrefs, int inflate_regexps, SV *client );
-void perl_mongo_sv_to_bson (bson_t * bson, SV *sv, AV *ids);
+void perl_mongo_sv_to_bson (bson_t * bson, SV *sv, int is_insert, AV *ids);
 void perl_mongo_sv_to_buffer(buffer * buf, SV *sv, AV *ids);
 
 void perl_mongo_serialize_string(buffer *buf, const char *str, unsigned int str_len);
